@@ -15,9 +15,9 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 # 02111-1307, USA.
 #
-""" Interface of a Credential Server
+"""Interface of a Credential Server.
 
-$Id: CredentialBase.py 28385 2005-10-18 09:29:24Z bdelbosc $
+$Id: CredentialBase.py 30282 2005-12-05 12:52:30Z bdelbosc $
 """
 
 class CredentialBaseServer:
