@@ -15,9 +15,9 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 # 02111-1307, USA.
 #
-"""Common XMLRPCServer
+"""Base class to build XML RPC daemon server.
 
-$Id: XmlRpcBase.py 29238 2005-11-08 10:07:25Z bdelbosc $
+$Id: XmlRpcBase.py 30282 2005-12-05 12:52:30Z bdelbosc $
 """
 import sys, os
 from socket import error as SocketError
