@@ -1,7 +1,7 @@
 # -*- coding: iso-8859-15 -*-
 """Simple FunkLoad test
 
-$Id: test_Simple.py 29238 2005-11-08 10:07:25Z bdelbosc $
+$Id: test_Simple.py 29381 2005-11-09 10:38:21Z bdelbosc $
 """
 import unittest
 from random import random
@@ -25,8 +25,6 @@ class Simple(FunkLoadTestCase):
         for i in range(nb_time):
             self.logd('Try %i' % i)
             for page in pages:
-                self.setUserAgent('toto')
-                self.addHeader('foo', 'bar')
                 self.get(server_url + page, description='Get %s' % page)
 
         # end of test -----------------------------------------------
